#
# spec file for package python-swift3
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define component swift3

%define version_unconverted 1.11.0.dev493

Name:           python-swift3
Version:        1.11.0~a0~dev493
Release:        1.1
Summary:        OpenStack Swift - Amazon S3 API Middleware
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/stackforge/swift3
Source:         http://tarballs.openstack.org/swift3/swift3-master.tar.gz
BuildRequires:  fdupes
BuildRequires:  openstack-suse-macros
BuildRequires:  python-pbr
BuildRequires:  python-setuptools
# Documentation requirements:
BuildRequires:  python-Sphinx
Requires:       python-lxml
Requires:       python-swift >= 2.1.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Swift3 Middleware for OpenStack Swift, allowing access to OpenStack swift via the Amazon S3 API.

%package test
Summary:        OpenStack Swift - Amazon S3 API Middleware - Testsuite
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-boto
Requires:       python-mock
Requires:       python-openstack.nose_plugin
Requires:       python-openstackclient >= 1.9.0

%description test
The Swift3 Middleware testsuite. It is used to verify the functionality
of the Swift3 Middleware for OpenStack Swift.

%prep
%setup -q -n swift3-%{version_unconverted}
%openstack_cleanup_prep

%build
python setup.py build
python setup.py build_sphinx

%install
python setup.py install --skip-build --prefix=%{_prefix} --root=%{buildroot}

### test subpackage
%openstack_test_package_install
%fdupes %{buildroot}%{_localstatedir}/lib/%{name}-test

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE README.md build/sphinx/html
%{python_sitelib}/%{component}/
%{python_sitelib}/%{component}-*.egg-info
%exclude %{python_sitelib}/%{component}/test*

%files test
%defattr(-,root,root)
%{_localstatedir}/lib/%{name}-test/
%{python_sitelib}/%{component}/test*

%changelog
* Tue Sep 13 2016 cloud-devel@suse.de
- Update to version swift3-1.11.0.dev491:
  Swift3 (1.11)
  * Amazon S3 Signature V4 support
  - To track newer authentication for Amazon Web service, Swift3 now
    supports Signature V4 authentication. Note that currently Signature
    V4 is available only with keystone authentication and >=9.0.0 keystone
    is required.
  * s3_token middleware migrated from keystonemiddleware repository
  - Following a discussion at OpenStack Austin Summit, the s3_token
    middleware has been migrated from keystonemiddlware to maintain in
    swift3. To use the newest maintained s3_token middleware, a few
    configuration changes in proxy-server.conf is needed.
  * Fix unexpected HTTP verb handling
  - Older swift3 is able to run any methods implemented in the controllers
    via HTTP verb. This fix limits the acceptable HTTP verbs to PUT, GET,
    HEAD, POST, and DELETE which are available at S3.
  * Delete segments bucket when the original bucket is deleted
  - To keep clean the swift environment, delete segment bucket and all
    segment objects in the bucket for multipart upload when the original
    bucket is deleted.
  * Copy Source Range support
  - Previously, we only supported copying complete objects for multipart
    uploads. Now we can optionally specify a single range to copy via
    x-amz-copy-source-range header.
  * swift3 version info available in /info
* Fri Feb 26 2016 cloud-devel@suse.de
- Update to version swift3-1.10.0.dev449:
  Swift3 (1.10)
  * Supported Python minimum version bumped to 2.7
  * S3Timestamp to ensure the transaction timestamp in Swift3
  - Sometimes Swift3 needs X-Timestamp value to show the request
    result to the client as the response body (e.g. copy result).
    However, older versions of swift3 don't have the way to decide
    the request timestamp. This stuff allows Swift3 to make its own
    timestamp when a request coming and supports a format which fits
    to S3 xml format.
  * Fix URL-encoded x-amz-copy-source
  - Fix a bug encoding again URL-encoded x-amz-copy-source.
  * Ignore Content-Type for Delete object request
  - A standard S3 client may set a header "Content-Type" into a DELETE
    request and it causes unexpected error in the backend pure Swift.
    To solve this, now swift3 drops the Content-Type header from the
    request only when it's a DELETE object request.
  * Other minor bug fixes and small improvements
* Fri Dec 11 2015 cloud-devel@suse.de
- Update to version swift3-1.9.0.dev418:
  Swift3 (1.9)
  * Date Header fixes (closes CVE-2015-8466)
  - Older versions of swift3 allow requests without any date headers,
    making them vulnerable to replay attacks. Now swift3 forces incomming
    requests to have either valid Date header or valid x-amz-date header.
  * Response fixes
  - Now swift3 returns correct (same syntax with actual S3) response
    in following case:
  - - content-type in ErrorResponse
  - - Etag in BucketListing
  * Allow to delete segments, when the DELETE request is for slo
  - If the incomming DELETE request is to slo object, swift3 now attempt
    to query multipart-manifest=delete to delete whole segments in the
    manifest. This will achieve to clean up part objects for multipart
    upload.
  * Accept chunked transfer-encodings
  * Update supported version of Keystone
  * Move to new namespace (from stackforge to openstack)
  * Other minor bug fixes and small improvements
* Fri Jun 12 2015 cloud-devel@suse.de
- Update to version swift3-1.8.0.dev375:
  Swift3 (1.8)
  * multi object deletion support
  - achieve the stuff in Swift3 and drop s3multi dependency off
  * multi object upload support
  - includes Initiate, Upload Part, Upload Part (copy),
    Abort, List (Uploads and Parts)
  * Swift 2.3.0 Support
  * x-amz-request-id is now transuction id in Swift
  * new ACL mechanism partially support
    Swift3 now has a couple of ACL scheme. One is a traditional scheme
    using native container ACL conpatible with backend Swift. The other
    is new scheme called 's3acl' that works as completely compatible with
    actual S3 ACLs. The new scheme is build espicially forcused on:
  - Single bucket namespace
  - Owner/Grant achievement
  - Object ACL support
    Note that the new scheme is still under development, so don't use it
    for production w/o enough testing.
* Mon May 18 2015 vuntz@suse.com
- Update _service to track tarball generated on
  tarballs.openstack.org.
- Switch to packaging style of openstack packages.
- Create a test subpackage.
- Update to version 1.7.0.dev372:
  + Add .gitreview file.
  + Update package data
  + Add tox-based tests support
  + Fix pep8 errors
  + Update .gitignore
  + Fix listing bucket when key contains special URL charcters
  + Fix type errors with s3multi
  + Fix an 'if' condition.
  + Use HTTP_METHOD_NOT_ALLOWED when invalid method is specified
  + make handle_request return callable
  + Add setup.cfg and pbr support.
  + Remove unnecessary urllib.unquote calls
  + Improve coverage report
  + Use openstack.nose_plugin for tests
  + Make more use of Swob for code cleanup
  + Remove pbr dependency at run time
  + Split controllers
  + Added swift3.Response
  + test: add FakeSwift
  + Use InternalError for unexpected server errors
  + Use lxml for processing XML
  + tox: add support for pylint
  + Fix Pre-Signed URL
  + acl: fix PUT bucket acl
  + Add a wrapper for lxml to handle XML namespace
  + Define S3 errors as exceptions
  + Added swift3.Request
  + Raise SignatureDoesNotMatch for unauthorized requests
  + request: move status code check into swift3.Request
  + Split controllers into separate modules
  + test: split TestSwift3 based on controller modules
  + test: add support for functional tests
  + Don't intervene with non-AWS HTTP authentication
  + test/functional: remove bc dependency
  + response: remove StatusMap class
  + controller: add UnsupportedController for unsupported features
  + request: add missing subresources for signature calculation
  + tests/functional: remove unused parameters
  + Make the swift3 config global
  + Use tenant name and user name for user id
  + etree: add support for xml validation
  + bucket: fix success code of HEAD request
  + tox: update swift version
  + cleanup dependency in tox.ini
  + request: add support for virtual-hosted-style access
  + Return errors when unsupported headers are specified
  + test/unit: remove unused method
  + Fix HEAD bucket request string problem.
  + request: remove unnecessary check
  + obj: add support for altering response header values
  + test/unit: forbid empty path_info
  + request: return InvalidURI for non-utf8 URI
  + Add test case for HEAD bucket requests.
  + service: ignores subresource queries for service requests
  + request: add helper to check the target resource type
  + cfg: set default values for swift3 config parameters
  + bucket: make max_bucket_listing configurable
  + Fix typo in swift3/response.py
  + response: drain response body on error
  + response: include resource_type in the MethodNotAllowed response
  + Fix Location header of PUT bucket response
  + Clean up Location header in Bucket Response
  + request: forbid request.body
  + bucket: handle location constraint requests
  + Set x-amz-id-2 and x-amz-request-id headers based on Swift txid
  + Check the target resource more strictly
  + response: add double quotes to etag headers
  + bucket: add missing type conversion
  + multi_delete: make content-md5 mandatory
  + cfg: convert types automatically based on default values
  + Remove unused variable
  + cfg: allow attribute access
  + request: raise InvalidDigest for non-base64-alphabet CONTENT_MD5
  + test/unit: allow running test directly
  + tox: update pep8 parameters based on the latest Swift
  + Make the swift3 logger global
  + test/unit: move swift3.etree test to test_etree.py
  + etree: handle invalid xml
  + multi_upload: preliminary support for S3 multi part upload
  + Unfold add_canonical_user()
  + Move x-amz-acl header handling into acl.py
  + multi_delete: limit the maximum number of objects
  + bucket: return delimiter only when it is specified in query
  + Remove string comparisons for illegal ACL
  + multi_delete: add support for quiet mode
  + multi_delete: return UserKeyMustBeSpecified when key is missing
  + etree: handle comments in xml
  + Add support for non-ascii string
  + tox: update swift version to 2.1.0
  + Add helper to decode and encode utf8
  + etree: add support for url-encoding
  + Check pipeline configuration
  + Add error response tests for object that are insufficient.
  + Update documentation to use keystoneauth name
  + Fix X-AMZ-ACL header is not applied
  + Fix Canned ACL Error with Empty Body
  + Fix set ACL fails to existing bucket
  + Add compatible with third party auth middleware.
  + Fix test_location unit test
  + Fix object copy requests.
  + Disable pylint failures
  + LOGGER can't output message to proxy.log.
  + Fix multipart upload is required SLO in pipeline
  + Draft: Acl class design for supporting S3 ACL
  + acl: add preliminary support for S3 ACL
  + acl: use S3 ACL for object and bucket APIs
  + Refactor test_s3_acl
  + Show warn/error log when no slo middleware
  + Draft: s3acl decorator
  + Support FakeSwift register overwritten
  + Fix 500 error when no DisplayName in request body.
  + Move tests related to s3_acl in the test_s3_acl.py to the appropriate files
  + Add S3 ACL for DELETE Multiple Objects
  + Fix object copy with empty source
  + Fix validation of invalid bucket name
  + acl: Skip acl check for all requests of Account.
  + Blind whole buckets with invalid name
  + Fix InternalError when RequestTimeout occurs
  + Add S3 ACL for Multipart Upload APIs
  + Draft: Split Request class for s3acl
  + ACL Handlers
  + Add unit test for GET Bucket includes subdir
  + Delete check of write permission of the object in PUT Object
  + Fix response of Get Bucket when IsTruncated is true and delimiter is specified
  + Return NotImplemented at POST object
  + Fix response of DELETE Multiple Objects without bucket write permission
  + Support x-amz-copy-source-if-* for PUT Object Copy
  + Support range for HEAD Object
  + Fix max-uploads, key-marker, prefix and upload-id-marker in queries of List Multipart Uploads
  + Fix max-parts, part-number-marker, and encoding-type in queries of List Parts
  + Add config paramater `pipeline_check` to enable/disable pipeline check
  + Support x-amz-copy-source-if-* for Upload Part Copy
  + Add check the range of partNumber for Upload part.
  + Assemble similar stuffs into a validation method
  + Fix a limit validation to be in integer range
  + Fix canned acl to be effective for s3_acl
  + Fix response of PUT Object Copy requests
  + Fix ACL of Multipart upload.
  + Cleanup pipeline_check config and its description
  + Fix response of Upload Part Copy requests
  + Fix response of Upload Part Copy requests
  + Fix to be able to change the maximum value of partNumber for Upload Part
  + Fix default maximum value of max-parts for List Parts
  + Fix Swift3 to skip S3 authorization after initial authentication
  + Support x-amz-meta-* for Initiate Multipart Upload
  + Fix the response of GET Service to get only buckets owner are request user
  + Use swift.common.utils.json
  + Force error instantiation
  + Remove handmade json patterns
  + Update README.
  + Keystone_token is no longer needed
  + Register swift3 info to swift APIs(/info).
  + Fix List Multipart Uploads to get multipart uploads contain slash in key
  + Fix the version of Swift that required to install Swift3
  + Fix get_validated_param and APIs related to this method
  + output access log of subrequests from swift3 to proxy-server
  + Update doc about force_swift_request_proxy_log
  + Draft: Change functional tests to the new structure.
  + Enable reset to retry up to RETRAY_COUNT
  + Add documentation on s3_test_client
  + Refactor Functional Test Cases
  + Add Functional Tests for PUT Object Copy
  + Small refactor on list uploads
  + Support delimiter for List Multipart Uploads
  + Add document and refactor a bit
  + Add Functional Tests of normal for ACL
  + Add functional tests for normal statuses of Delete Multiple Objects
  + Add functional error tests for Delete Multiple Objects
  + Fix error handling of reset method in s3_test_client.py
  + Add functional tests of error for ACL
  + Add environment of s3acl to tox
  + Fix DELETE object response
  + Move container_info to Request class
  + Add Functional Tests of input param test of normal for DELETE Multiple Objects
  + Add Functional Tests of input parameter test of normal for Object
  + Make multi-range functional test to be more strict
  + Use common libraries for timestamp
  + Add src to src copy functional test
  + Use singular variable name for the single content
  + Add Functional Tests of input parameter test of normal for Bucket
  + Add assertion for Copied Object
  + Fix list multi uploads response
  + Object Creation Assertion, everywhare
  + assert_common_response_headers to TestCase class
  + Fix initiate multi_upload
  + Fix get_container_info authentication
  + list uploads should fail w/o the bucket
  + Add functional tests for normal statuses of Multipart Upload
  + Use singular variable name for the single content
  + More strict functional tests for multi-upload
  + Fix last-modified format on the copy result
  + Add mktime function to test.functional.utils
  + Fix lost response headers
  + Fix upload part error handling
  + Refactor container existence checking
  + Move acl related functions to acl_utils.py
  + Fix non-exist bucket bugs on multi-upload
  + Fix invalid canned acl response
  + Add functional error tests for Multipart Upload
  + S3 allows fewer etags than actual uploaded parts
  + Add unit tests for test_subresource
  + More tests for logging controller for coverage
* Thu Nov 21 2013 cloud-devel@suse.de
- Update to latest git (9a2ce5e):
  + preven double-quoting object name
  + fix requests without object_name
* Wed Nov 13 2013 speilicke@suse.com
- Update to version 1.7+git.1379116028.c367e2f:
  + Issue #49 - fixed Date and ExpireDate checking logic Cleaned up PEP8 and Flake8 formatting errors.canonical_string refactoring + fix typing in middleware comment
  + Undo part of patch by Willys
  + Add a error of EntityTooLarge
  + fix signature generation
- Fix set_version service by changing the version from "v1.7..." to "1.7".
  Since RPM comparison says numbers are bigger than characters, it's just
  an ordinary version update
* Tue Jul  2 2013 speilicke@suse.com
- Install HTML documentation
* Tue Jul  2 2013 speilicke@suse.com
- Initial version
